:
# NAME:
#	mklofs.sh - make loopback mounts
#
# SYNPOSIS:
#	cat list | mklofs.sh
#
# DESCRIPTION:
#	This script should be run before config.sh to prepare
#	any loopback mounts.
#
#	It handles input like:
#.nf
#
#		"dir" - "mpt" [rest]
#
#	or
#
#		"dir" "mpt" [rest]
#
#	If "mpt" exists but "dir" does not we mv(1) "mpt" to "dir".
#	We then check that both dirs exists, add an entry to vfstab if
#	need be and do the mount (if "DESTDIR" is unset or '/').
#
# BUGS:
#	Will bail out if it does not know the correct fstype for
#	loopback mounts.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: mklofs.sh,v 1.4 2004/04/17 05:33:05 sjg Exp $
#
#	@(#)Copyright (c) 1998 Simon J. Gerraty. All rights reserved.
#	
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to use, modify and distribute this source code 
#	is granted subject to the following conditions.
#	1/ that the above copyright notice and this notice 
#	are preserved in all copies and that due credit be given 
#	to the author.	
#	2/ that any changes to this code are clearly commented 
#	as such so that the author does not get blamed for bugs 
#	other than his own.
#	3/ If there is an accompanying License file its provisions
#	must also be met.
#	
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Myname=mklofs

opts=${1:-rw}

if [ x$OSREL = x ]; then
        Mydir=`dirname $0`
        for d in $Mydir/../etc/rc_d /etc/rc_d $RC_D
        do
                [ -s $d/os.sh ] && . $d/os.sh
	done
fi
DEST_OS=${DEST_OS:-$OS}
DEST_OSREL=${DEST_OSREL:-$OSREL}
DEST_MACHINE=${DEST_MACHINE:-$MACHINE}
DEST_MACHINE_ARCH=${DEST_MACHINE_ARCH:-$MACHINE_ARCH}
DEST_MACHINE_ARCH=${DEST_MACHINE_ARCH:-$DEST_MACHINE}

case "$DEST_OS$DEST_OSREL" in
SunOS5*)
        FSTAB=$DESTDIR/etc/vfstab;;
*)	FSTAB=$DESTDIR/etc/fstab;;
esac
case "$DEST_OS$DEST_OSREL" in
NetBSD*)        FSTYPE=null; FT2=; FTREST="$opts 0 0";;
SunOS4*)	FSTYPE=lo; FT2=; FTREST="$opts 0 0";;
SunOS5*)	FSTYPE=lofs; FT2=-; FTREST="- yes $opts";;
HP-UX*)		FSTYPE=lofs; FT2=; FTREST="$opts 0 0";;
esac

[ "$FSTYPE" ] || { echo "Need to know what $DEST_OS$DEST_OSREL looback mounts are" >&2; exit 1; }

while read dir chk mpt rest
do
	case $chk in
	-) ;;
	*) mpt=$chk;;
	esac
        # don't duplicate entries or muck up a real device entry
        case `grep "[ 	]$mpt[ 	]" $FSTAB` in
	"") ;;
	*) continue;;
	esac
	case `ls -ld $DESTDIR$mpt 2>/dev/null` in
	""|d*)	;;
	*)	echo "$Myname: skipping $mpt: not a directory" >&2; continue;;
	esac
	echo "$dir $FT2 $mpt $FSTYPE $FTREST" >> $FSTAB
        if [ -d $DESTDIR$mpt -a ! -d $DESTDIR$dir ]; then
                d=`dirname $DESTDIR$dir`
                mkdir -p $d
                mv $DESTDIR$mpt $DESTDIR$dir
	fi
	mkdir -p $DESTDIR$dir $DESTDIR$mpt
	if [ ${DESTDIR:-/} = / ]; then
		mount $mpt
	fi
done
